Documentation
¶
Overview ¶
Package context provides gorelease context which is passed through the pipeline.
The context extends the standard library context and add a few more fields and other things, so pipes can gather data provided by previous pipes without really knowing each other.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Context ¶
type Context struct {
ctx.Context
Config config.Project
Env Env
SkipTokenCheck bool
Token string
TokenType TokenType
Git GitInfo
Date time.Time
Artifacts artifact.Artifacts
ReleaseURL string
ReleaseNotes string
ReleaseNotesFile string
ReleaseNotesTmpl string
ReleaseHeaderFile string
ReleaseHeaderTmpl string
Version string
ModulePath string
Snapshot bool
SkipPostBuildHooks bool
SkipPublish bool
SkipAnnounce bool
SkipSign bool
SkipValidate bool
SkipSBOMCataloging bool
RmDist bool
PreRelease bool
Deprecated bool
Parallelism int
Semver Semver
Runtime Runtime
}
Context carries along some data through the pipes.
func NewWithTimeout ¶
NewWithTimeout new context with the given timeout.
type Env ¶ added in v0.104.2
Env is the environment variables.
type GitInfo ¶
type GitInfo struct {
Branch string
CurrentTag string
PreviousTag string
Commit string
ShortCommit string
FullCommit string
CommitDate time.Time
URL string
Summary string
TagSubject string
TagContents string
TagBody string
}
GitInfo includes tags and diffs used in some point.
Click to show internal directories.
Click to hide internal directories.